@@ -25,9 +25,9 @@
 #include FIDES_RAPIDJSON(rapidjson/filereadstream.h)
 // clang-format on
 
-#include <vtkm/cont/CoordinateSystem.h>
-#include <vtkm/cont/DataSet.h>
-#include <vtkm/cont/UnknownCellSet.h>
+#include <viskores/cont/CoordinateSystem.h>
+#include <viskores/cont/DataSet.h>
+#include <viskores/cont/UnknownCellSet.h>
 
 #include <fides/CellSet.h>
 #include <fides/CoordinateSystem.h>
@@ -64,13 +64,27 @@ public:
     }
     else
     {
-      rapidjson::Document doc = this->GetJSONDocument(dataModel, inputType);
-      this->ParsingChecks(doc, dataModel, inputType);
+      rapidjson::Document doc = DataSetReaderImpl::GetJSONDocument(dataModel, inputType);
+      DataSetReaderImpl::ParsingChecks(doc, dataModel, inputType);
       this->ReadJSON(doc);
     }
+    std::string relativePath;
+    if (inputType != DataModelInput::JSONString)
+    {
+      size_t pos = dataModel.find_last_of("\\/");
+      if (pos != std::string::npos)
+      {
+        relativePath = dataModel.substr(0, pos + 1);
+      }
+      else
+      {
+        relativePath = "./";
+      }
+    }
     for (auto it : this->DataSources)
     {
       it.second->CreateSharedPoints = createSharedPoints;
+      it.second->RelativePath = relativePath;
     }
 
     this->SetDataSourceParameters(params);
@@ -85,7 +99,7 @@ public:
     this->CellSet.reset();
   }
 
-  rapidjson::Document GetJSONDocument(const std::string& dataModel, DataModelInput inputType)
+  static rapidjson::Document GetJSONDocument(const std::string& dataModel, DataModelInput inputType)
   {
     rapidjson::Document d;
     if (inputType == DataModelInput::JSONFile)
@@ -295,9 +309,9 @@ public:
     return val;
   }
 
-  void ParsingChecks(rapidjson::Document& document,
-                     const std::string& fileName,
-                     DataModelInput inputType)
+  static void ParsingChecks(rapidjson::Document& document,
+                            const std::string& fileName,
+                            DataModelInput inputType)
   {
     std::string nameStr;
     if (inputType == DataModelInput::JSONFile)
@@ -375,7 +389,7 @@ public:
     }
   }
 
-  std::vector<vtkm::cont::CoordinateSystem> ReadCoordinateSystem(
+  std::vector<viskores::cont::CoordinateSystem> ReadCoordinateSystem(
     const std::unordered_map<std::string, std::string>& paths,
     const fides::metadata::MetaData& selections)
   {
@@ -386,7 +400,7 @@ public:
     return this->CoordinateSystem->Read(paths, this->DataSources, selections);
   }
 
-  std::vector<vtkm::cont::UnknownCellSet> ReadCellSet(
+  std::vector<viskores::cont::UnknownCellSet> ReadCellSet(
     const std::unordered_map<std::string, std::string>& paths,
     const fides::metadata::MetaData& selections)
   {
@@ -462,7 +476,8 @@ public:
   struct GetTimeValueFunctor
   {
     template <typename T, typename S>
-    VTKM_CONT void operator()(const vtkm::cont::ArrayHandle<T, S>& array, double& time) const
+    VISKORES_CONT void operator()(const viskores::cont::ArrayHandle<T, S>& array,
+                                  double& time) const
     {
       time = static_cast<double>(array.ReadPortal().Get(0));
     }
@@ -506,14 +521,7 @@ public:
     if (it != this->DataSources.end())
     {
       auto ds = it->second;
-      auto itr = paths.find(this->StepSource);
-      if (itr == paths.end())
-      {
-        throw std::runtime_error("Could not find data_source with name " + this->StepSource +
-                                 " among the input paths.");
-      }
-      std::string path = itr->second + ds->FileName;
-      ds->OpenSource(path);
+      ds->OpenSource(paths, this->StepSource);
 
       // StreamingMode only gets set on the first PrepareNextStep, but
       // for streaming PrepareNextStep has to be called before ReadMetaData anyway
@@ -529,8 +537,8 @@ public:
           if (timeAH.GetNumberOfValues() == 1)
           {
             double timeVal;
-            timeAH.CastAndCallForTypes<vtkm::TypeListScalarAll,
-                                       vtkm::List<vtkm::cont::StorageTagBasic>>(
+            timeAH.CastAndCallForTypes<viskores::TypeListScalarAll,
+                                       viskores::List<viskores::cont::StorageTagBasic>>(
               GetTimeValueFunctor(), timeVal);
             fides::metadata::Time time(timeVal);
             metaData.Set(fides::keys::TIME_VALUE(), time);
@@ -546,15 +554,15 @@ public:
         if (!timeVec.empty())
         {
           auto& timeAH = timeVec[0];
-          vtkm::cont::UnknownArrayHandle tUAH = timeAH.NewInstanceFloatBasic();
+          viskores::cont::UnknownArrayHandle tUAH = timeAH.NewInstanceFloatBasic();
           tUAH.CopyShallowIfPossible(timeAH);
-          vtkm::cont::ArrayHandle<vtkm::FloatDefault> timeCasted =
-            tUAH.AsArrayHandle<vtkm::cont::ArrayHandle<vtkm::FloatDefault>>();
+          viskores::cont::ArrayHandle<viskores::FloatDefault> timeCasted =
+            tUAH.AsArrayHandle<viskores::cont::ArrayHandle<viskores::FloatDefault>>();
 
           auto timePortal = timeCasted.ReadPortal();
           fides::metadata::Vector<double> time;
           time.Data.resize(timePortal.GetNumberOfValues());
-          vtkm::cont::ArrayPortalToIterators<decltype(timePortal)> iterators(timePortal);
+          viskores::cont::ArrayPortalToIterators<decltype(timePortal)> iterators(timePortal);
           std::copy(iterators.GetBegin(), iterators.GetEnd(), time.Data.begin());
           metaData.Set(fides::keys::TIME_ARRAY(), time);
         }
@@ -590,20 +598,14 @@ public:
     if (it != this->DataSources.end())
     {
       auto ds = it->second;
-      auto itr = paths.find(this->StepSource);
-      if (itr == paths.end())
-      {
-        throw std::runtime_error("Could not find data_source with name " + this->StepSource +
-                                 " among the input paths.");
-      }
-      std::string path = itr->second + ds->FileName;
-      ds->OpenSource(path);
+      ds->OpenSource(paths, this->StepSource);
       return this->CoordinateSystem->GetGroupNames(paths, this->DataSources);
     }
     return {};
   }
 
-  void PostRead(std::vector<vtkm::cont::DataSet>& pds, const fides::metadata::MetaData& selections)
+  void PostRead(std::vector<viskores::cont::DataSet>& pds,
+                const fides::metadata::MetaData& selections)
   {
     this->CoordinateSystem->PostRead(pds, selections);
     this->CellSet->PostRead(pds, selections);
@@ -639,14 +641,7 @@ public:
     {
       auto& ds = *(source.second);
       std::string name = source.first;
-      auto itr = paths.find(name);
-      if (itr == paths.end())
-      {
-        throw std::runtime_error("Could not find data_source with name " + name +
-                                 " among the input paths.");
-      }
-      std::string path = itr->second + ds.FileName;
-      ds.OpenSource(path);
+      ds.OpenSource(paths, name);
       auto rc = ds.BeginStep();
       while (rc == StepStatus::NotReady)
       {
@@ -672,7 +667,7 @@ public:
   std::shared_ptr<fides::predefined::InternalMetadataSource> MetadataSource = nullptr;
   std::shared_ptr<fides::datamodel::CoordinateSystem> CoordinateSystem = nullptr;
   std::shared_ptr<fides::datamodel::CellSet> CellSet = nullptr;
-  using FieldsKeyType = std::pair<std::string, vtkm::cont::Field::Association>;
+  using FieldsKeyType = std::pair<std::string, viskores::cont::Field::Association>;
   std::map<FieldsKeyType, std::shared_ptr<fides::datamodel::Field>> Fields;
   std::string StepSource;
   std::string TimeVariable;
@@ -785,7 +780,7 @@ fides::metadata::MetaData DataSetReader::ReadMetaData(
   return this->Impl->ReadMetaData(paths, groupName);
 }
 
-vtkm::cont::PartitionedDataSet DataSetReader::ReadDataSet(
+viskores::cont::PartitionedDataSet DataSetReader::ReadDataSet(
   const std::unordered_map<std::string, std::string>& paths,
   const fides::metadata::MetaData& selections)
 {
@@ -802,12 +797,18 @@ vtkm::cont::PartitionedDataSet DataSetReader::ReadDataSet(
 
   // for(size_t i=0; i<ds.GetNumberOfPartitions(); i++)
   // {
-  //   vtkm::io::writer::VTKDataSetWriter writer(
+  //   viskores::io::writer::VTKDataSetWriter writer(
   //     "output" + std::to_string(i) + ".vtk");
   //   writer.WriteDataSet(ds.GetPartition(i));
   // }
 
-  return vtkm::cont::PartitionedDataSet(ds);
+  return viskores::cont::PartitionedDataSet(ds);
+}
+
+viskores::cont::PartitionedDataSet DataSetReader::ReadDataSet(
+  const fides::metadata::MetaData& selections)
+{
+  return this->ReadDataSet(std::unordered_map<std::string, std::string>{}, selections);
 }
 
 std::set<std::string> DataSetReader::GetGroupNames(
@@ -822,7 +823,7 @@ StepStatus DataSetReader::PrepareNextStep(const std::unordered_map<std::string,
   return this->Impl->BeginStep(paths);
 }
 
-vtkm::cont::PartitionedDataSet DataSetReader::ReadStep(
+viskores::cont::PartitionedDataSet DataSetReader::ReadStep(
   const std::unordered_map<std::string, std::string>& paths,
   const fides::metadata::MetaData& selections)
 {
@@ -832,15 +833,15 @@ vtkm::cont::PartitionedDataSet DataSetReader::ReadStep(
 // Returning vector of DataSets instead of PartitionedDataSet because
 // PartitionedDataSet::GetPartition always returns a const DataSet, but
 // we may need to update the DataSet in the PostRead call
-std::vector<vtkm::cont::DataSet> DataSetReader::ReadDataSetInternal(
+std::vector<viskores::cont::DataSet> DataSetReader::ReadDataSetInternal(
   const std::unordered_map<std::string, std::string>& paths,
   const fides::metadata::MetaData& selections)
 {
-  std::vector<vtkm::cont::CoordinateSystem> coordSystems =
+  std::vector<viskores::cont::CoordinateSystem> coordSystems =
     this->Impl->ReadCoordinateSystem(paths, selections);
-  std::vector<vtkm::cont::UnknownCellSet> cellSets = this->Impl->ReadCellSet(paths, selections);
+  std::vector<viskores::cont::UnknownCellSet> cellSets = this->Impl->ReadCellSet(paths, selections);
   size_t nPartitions = cellSets.size();
-  std::vector<vtkm::cont::DataSet> dataSets(nPartitions);
+  std::vector<viskores::cont::DataSet> dataSets(nPartitions);
   for (size_t i = 0; i < nPartitions; i++)
   {
     if (i < coordSystems.size())
@@ -865,7 +866,7 @@ std::vector<vtkm::cont::DataSet> DataSetReader::ReadDataSetInternal(
       auto itr = this->Impl->Fields.find(std::make_pair(field.Name, field.Association));
       if (itr != this->Impl->Fields.end())
       {
-        std::vector<vtkm::cont::Field> fieldVec =
+        std::vector<viskores::cont::Field> fieldVec =
           itr->second->Read(paths, this->Impl->DataSources, selections);
         for (size_t i = 0; i < nPartitions; i++)
         {
@@ -881,7 +882,7 @@ std::vector<vtkm::cont::DataSet> DataSetReader::ReadDataSetInternal(
   {
     for (auto& field : this->Impl->Fields)
     {
-      std::vector<vtkm::cont::Field> fields =
+      std::vector<viskores::cont::Field> fields =
         field.second->Read(paths, this->Impl->DataSources, selections);
       for (size_t i = 0; i < nPartitions; i++)
       {
